package com.lantone.qc.kernel.catalogue.invasiveoperation;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.DoctorAdviceDoc;
import com.lantone.qc.pub.model.doc.InvasiveOperationDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.apache.commons.lang3.time.DateUtils;
import org.springframework.stereotype.Component;

import java.util.Date;
import java.util.List;
import java.util.Map;

/**
 * @ClassName : INVA03153
 * @Description : 缺有创诊疗操作记录单
 * @Author : wsy
 * @Date: 2021-01-07 13:39
 */
@Component
public class INVA03153 extends QCCatalogue {
    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        List<DoctorAdviceDoc> doctorAdviceDocs = inputInfo.getDoctorAdviceDocs();
        List<String> haveOperationList = Content.haveOperationList;
        boolean flag=false;
        if(ListUtil.isNotEmpty(doctorAdviceDocs)){
            for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocs) {
                //取长期临时医嘱,不为作废医嘱
                if(doctorAdviceDoc.getStructureMap()==null) {
                    continue;
                }
                Map<String, String> doctorAdviceDocStructureMap = doctorAdviceDoc.getStructureMap();
                String adviceType = doctorAdviceDocStructureMap.get(Content.doctorAdviceType);
                if (StringUtil.isEmpty(adviceType)) {
                    continue;
                }
                if (adviceType.equals(Content.standingOrder) || adviceType.equals(Content.statOrder)) {
                    String adviceState = doctorAdviceDocStructureMap.get(Content.doctorAdviceState);
                    if (StringUtil.isEmpty(adviceState)) {
                        continue;
                    }
                    if (!Content.cancellationOrderList.contains(adviceState)) {
                        String medicalOrderName = doctorAdviceDoc.getStructureMap().get(Content.medicalOrderName);
                        if(StringUtil.isBlank(medicalOrderName)) {
                            continue;
                        }
                        //判断医嘱是否包含有创
                        for (String haveOperation : haveOperationList) {
                            if(medicalOrderName.contains(haveOperation)){
                                flag=true;
                            }
                        }
                    }
                }
            }
        }
        if(flag){
            status.set("-1");
            //含有创操作患者，判断是否含记录单
            List<InvasiveOperationDoc> invasiveOperationDocs = inputInfo.getInvasiveOperationDocs();
            if(ListUtil.isEmpty(invasiveOperationDocs)||invasiveOperationDocs.size()==0){
                return;
            }else {
                status.set("0");
            }
        }
    }
}
