package com.lantone.qc.kernel.catalogue.threelevelward;

import com.lantone.qc.kernel.catalogue.QCCatalogue;
import com.lantone.qc.pub.Content;
import com.lantone.qc.pub.model.InputInfo;
import com.lantone.qc.pub.model.OutputInfo;
import com.lantone.qc.pub.model.doc.DoctorAdviceDoc;
import com.lantone.qc.pub.model.doc.transferrecord.TransferIntoDoc;
import com.lantone.qc.pub.model.doc.transferrecord.TransferOutDoc;
import com.lantone.qc.pub.model.doc.transferrecord.TransferRecordDoc;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.pub.util.StringUtil;
import org.springframework.stereotype.Component;

import java.util.List;
import java.util.Map;

/**
 * @ClassName : THR03137
 * @Description : 缺转入记录
 * @Author : rengb
 * @Date: 2020-03-06 17:28
 */
@Component
public class THR03137 extends QCCatalogue {

    public void start(InputInfo inputInfo, OutputInfo outputInfo) {
        status.set("0");
        boolean flag=false;
        //首先判断医嘱中是否包含转科相关信息
        List<DoctorAdviceDoc> doctorAdviceDocs = inputInfo.getDoctorAdviceDocs();
        if(ListUtil.isEmpty(doctorAdviceDocs)){
            return;
        }
        for (DoctorAdviceDoc doctorAdviceDoc : doctorAdviceDocs) {
            //取长期临时医嘱,不为作废医嘱
            if(doctorAdviceDoc.getStructureMap()!=null){
                Map<String, String> doctorAdviceDocStructureMap = doctorAdviceDoc.getStructureMap();
                String adviceType = doctorAdviceDocStructureMap.get(Content.doctorAdviceType);
                if(StringUtil.isNotEmpty(adviceType)){
                    if(adviceType.equals(Content.standingOrder)||adviceType.equals(Content.statOrder)){
                        String adviceState = doctorAdviceDocStructureMap.get(Content.doctorAdviceState);
                        if(StringUtil.isNotEmpty(adviceState)){
                            if(!Content.cancellationOrderList.contains(adviceState)){
                                //医嘱若是包含  转*科/科*转则为一个转科患者
                                String medicalOrderName = doctorAdviceDoc.getStructureMap().get(Content.medicalOrderName);
                                if(StringUtil.isBlank(medicalOrderName)) {
                                    continue;
                                }
                                String rex1="[\\s\\S]*(?=转)[\\s\\S]{0,6}(?=科)[\\s\\S]*";
                                String rex2="[\\s\\S]*(?=科)[\\s\\S]{0,6}(?=转)[\\s\\S]*";
                                if(medicalOrderName.matches(rex1)||medicalOrderName.matches(rex2)) {
                                    flag = true;
                                    break ;
                                }
                            }
                        }
                    }
                }
            }
        }
        //为转科人员判断是否有转出记录
        if(flag){
            status.set("-1");
            TransferRecordDoc transferRecordDocs = inputInfo.getTransferRecordDocs();
            if(transferRecordDocs==null){
                return;
            }
            List<TransferIntoDoc> transferIntoDocs = transferRecordDocs.getTransferIntoDocs();
            if(ListUtil.isNotEmpty(transferIntoDocs) || transferIntoDocs.size()>0){
                //转出记录存在
                status.set("0");
                return;
            }

        }

    }


}